summaryrefslogtreecommitdiff
path: root/nuttx/binfmt/binfmt_execmodule.c
diff options
context:
space:
mode:
authorGregory Nutt <gnutt@nuttx.org>2014-08-22 12:32:34 -0600
committerGregory Nutt <gnutt@nuttx.org>2014-08-22 12:32:34 -0600
commit440d27c51fed1c66e883a6d0584599e2d0569a94 (patch)
tree8d392b85ac509e0c0e26d1c4c1a8338417771381 /nuttx/binfmt/binfmt_execmodule.c
parent3ee26908593dc30b07686f8cb3f8e23fa8ad12d5 (diff)
downloadnuttx-440d27c51fed1c66e883a6d0584599e2d0569a94.tar.gz
nuttx-440d27c51fed1c66e883a6d0584599e2d0569a94.tar.bz2
nuttx-440d27c51fed1c66e883a6d0584599e2d0569a94.zip
An address environment is the property of a task group, not of a thread
Diffstat (limited to 'nuttx/binfmt/binfmt_execmodule.c')
-rw-r--r--nuttx/binfmt/binfmt_execmodule.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/nuttx/binfmt/binfmt_execmodule.c b/nuttx/binfmt/binfmt_execmodule.c
index 13c692018..c765724bd 100644
--- a/nuttx/binfmt/binfmt_execmodule.c
+++ b/nuttx/binfmt/binfmt_execmodule.c
@@ -1,7 +1,7 @@
/****************************************************************************
* binfmt/binfmt_execmodule.c
*
- * Copyright (C) 2009, 2013 Gregory Nutt. All rights reserved.
+ * Copyright (C) 2009, 2013-2014 Gregory Nutt. All rights reserved.
* Author: Gregory Nutt <gnutt@nuttx.org>
*
* Redistribution and use in source and binary forms, with or without
@@ -205,10 +205,10 @@ int exec_module(FAR const struct binary_s *binp)
up_initial_state(&tcb->cmn);
#endif
/* Assign the address environment to the task */
#ifdef CONFIG_ADDRENV
- ret = up_addrenv_assign(binp->addrenv, &tcb->cmn);
+ ret = up_addrenv_assign(binp->addrenv, tcb->group);
if (ret < 0)
{
err = -ret;
@@ -205,10 +205,10 @@ int exec_module(FAR const struct binary_s *binp)
up_initial_state(&tcb->cmn);
#endif
- /* Assign the address environment to the task */
+ /* Assign the address environment to the new task group */
#ifdef CONFIG_ADDRENV